@@ -494,12 +494,10 @@ module TestNetHTTP_version_1_1_methods
 
   def test_s_post
     url = "http://#{config('host')}:#{config('port')}/?q=a"
-    res = assert_warning(/Content-Type did not set/) do
-      Net::HTTP.post(
-              URI.parse(url),
-              "a=x")
-    end
-    assert_equal "application/x-www-form-urlencoded", res["Content-Type"]
+    res = Net::HTTP.post(
+            URI.parse(url),
+            "a=x")
+    assert_equal "application/octet-stream", res["Content-Type"]
     assert_equal "a=x", res.body
     assert_equal url, res["X-request-uri"]
 
@@ -565,14 +563,12 @@ module TestNetHTTP_version_1_1_methods
       conn = Net::HTTP.new('localhost', port)
       conn.write_timeout = EnvUtil.apply_timeout_scale(0.01)
       conn.read_timeout = EnvUtil.apply_timeout_scale(0.01) if windows?
-      conn.open_timeout = EnvUtil.apply_timeout_scale(0.1)
+      conn.open_timeout = EnvUtil.apply_timeout_scale(1)
 
       th = Thread.new do
         err = !windows? ? Net::WriteTimeout : Net::ReadTimeout
         assert_raise(err) do
-          assert_warning(/Content-Type did not set/) do
-            conn.post('/', "a"*50_000_000)
-          end
+          conn.post('/', "a"*50_000_000)
         end
       end
       assert th.join(EnvUtil.apply_timeout_scale(10))
@@ -589,9 +585,9 @@ module TestNetHTTP_version_1_1_methods
       port = server.addr[1]
 
       conn = Net::HTTP.new('localhost', port)
-      conn.write_timeout = 0.01
-      conn.read_timeout = 0.01 if windows?
-      conn.open_timeout = 0.1
+      conn.write_timeout = EnvUtil.apply_timeout_scale(0.01)
+      conn.read_timeout = EnvUtil.apply_timeout_scale(0.01) if windows?
+      conn.open_timeout = EnvUtil.apply_timeout_scale(1)
 
       req = Net::HTTP::Post.new('/')
       data = "a"*50_000_000
